#!/usr/bin/python3
#
# Author: Markus Fuchs (fuchs@sero-systems.de)
# Created: 2019-08-29
#

import dbus

NM_BUS_NAME = "org.freedesktop.NetworkManager"
NM_BUS_PATH = "/org/freedesktop/NetworkManager"

# Device states from include/NetworkManager.h
device_states = {
    0: "Unknown",
    10: "Unmanaged",
    20: "Unavailable",
    30: "Disconnected",
    40: "Prepare",
    50: "Config",
    60: "Need Auth",
    70: "IP Config",
    80: "IP Check",
    90: "Secondaries",
    100: "Activated",
    110: "Deactivating",
    120: "Failed"
}

connectivity_states = {
    0: "Unknown",
    1: "Activating",
    2: "Activated",
    3: "Deactivating",
    4: "Deactivated"
}

nm_state = {
    0: "Unknown",
    10: "Asleep",
    20: "Disconnected",
    30: "Disconnecting",
    40: "Connecting",
    50: "Connected-Local",
    60: "Connected-Site",
    70: "Connected-Global"
}

# See https://developer.gnome.org/NetworkManager/stable/nm-dbus-types.html#NM80211Mode
nm_80211_mode = {0: "UNKNOWN",
                 1: "ADHOC",
                 2: "INFRA",
                 3: "AP",
                 4: "MESH"}

# See https://developer.gnome.org/NetworkManager/unstable/nm-dbus-types.html#NMDeviceType
nm_device_type = {
    0: "UNKNOWN",
    1: "ETHERNET",
    2: "WIFI",
    3: "UNUSED1",
    4: "UNUSED2",
    5: "BT",
    6: "OLPC_MESH",
    7: "WIMAX",
    8: "MODEM",
    9: "INFINIBAND",
    10: "BOND",
    11: "VLAN",
    12: "ADSL",
    13: "BRIDGE",
    14: "GENERIC",
    15: "TEAM",
    16: "TUN",
    17: "IP_TUNNEL",
    18: "MACVLAN",
    19: "VXLAN",
    20: "VETH",
    21: "MACSEC",
    22: "DUMMY",
    23: "PPP",
    24: "OVS_INTERFACE",
    25: "OVS_PORT",
    26: "OVS_BRIDGE",
    27: "WPAN",
    28: "6LOWPAN",
    29: "WIREGUARD",
    30: "WIFI_P2P"
}

DEFAULT_WIFI_HOTSPOT_SETTINGS = {
    "connection": {
        "type": "802-11-wireless",
        "uuid": "",
        "id": "wifi-default"
    },
    "802-11-wireless": {
        "ssid": dbus.ByteArray("es-sensor".encode("utf-8")),
        "mode": "ap",
        "band": "bg",
        "channel": dbus.UInt32(1)
    },
    "802-11-wireless-security": {
        "key-mgmt": "wpa-psk",
        "psk": "electrosense",
    },
    "ipv4": {
        "method": "shared",
        "address-data": dbus.Array([{"address": "10.0.1.1", "prefix": dbus.UInt32(24)}],
                                   signature=dbus.Signature("a{sv}")),
    },
    "ipv6": {"method": "ignore"}
}

DEFAULT_ETHERNET_SETTINGS = {
    "802-3-ethernet": {"duplex": "full"},
    "connection": {
        "type": "802-3-ethernet",
        "id": "wired-default"
    },
    "ipv4": {"method": "auto"},
    "ipv6": {"method": "ignore"}
}


def conn_nm():
    bus = dbus.SystemBus()
    settings = dbus.Interface(bus.get_object(NM_BUS_NAME, "/org/freedesktop/NetworkManager/Settings"),
                              "org.freedesktop.NetworkManager.Settings")
    manager = dbus.Interface(bus.get_object(NM_BUS_NAME, NM_BUS_PATH), NM_BUS_NAME)

    return bus, settings, manager