#!/usr/bin/python3
#
# Author: Markus Fuchs (fuchs@sero-systems.de)
# Created: 2019-08-14
#
#

import logging

logger = logging.getLogger("sysinfo")


def get_cpu_temp():
    """Get RPi internal temperature in °C"""
    try:
        with open("/sys/class/thermal/thermal_zone0/temp", "r") as f:
            return float(f.readline()) / 1000
    except Exception as e:
        logger.error("Failed to get temperature")
        logger.error(e)
        return None


def get_model():
    """Get RPi Model"""
    try:
        with open("/proc/device-tree/model", "r") as f:
            return f.readline().replace("\u0000", "")
    except Exception as e:
        logger.error("Failed to get model")
        logger.error(e)
        return None


def get_serial():
    """get ElectroSense serial number (currently MAC address of eth0"""
    try:
        with open("/sys/class/net/eth0/address", "r") as f:
            addr = f.read()
            return int(addr.replace(":", "")[0:12], 16)
    except Exception as e:
        logger.error("Failed to get serial")
        logger.error(e)
        return None


if __name__ == "__main__":
    LOG_FORMAT = "%(asctime)-15s %(name)s[%(threadName)s] %(levelname)-7s %(message)s"
    logging.basicConfig(level=logging.DEBUG, format=LOG_FORMAT)

    logger.info(get_cpu_temp())
    logger.info(get_model())
    logger.info(get_serial())
